==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebToggleViewEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebToggleViewEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebToggleViewEventArgsDetailDescription, _super);
    function WebToggleViewEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.m = null;
        return _this;
    }
    WebToggleViewEventArgsDetailDescription.prototype.get_type = function () {
        return "WebToggleViewEventArgsDetail";
    };
    Object.defineProperty(WebToggleViewEventArgsDetailDescription.prototype, "id", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.e("Id");
        },
        enumerable: true,
        configurable: true
    });
    WebToggleViewEventArgsDetailDescription.$t = markType(WebToggleViewEventArgsDetailDescription, 'WebToggleViewEventArgsDetailDescription', WebBaseEventArgsDetailDescription.$);
    WebToggleViewEventArgsDetailDescription.__marshalByValue1 = true;
    WebToggleViewEventArgsDetailDescription.__marshalByValueAlias1 = "ToggleViewEventArgsDetail";
    return WebToggleViewEventArgsDetailDescription;
}(WebBaseEventArgsDetailDescription));
export { WebToggleViewEventArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebToggleViewEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebToggleViewEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebToggleViewEventArgsDetailDescription, _super);
    function WebToggleViewEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.o = null;
        return _this;
    }
    WebToggleViewEventArgsDetailDescription.prototype.get_type = function () {
        return "WebToggleViewEventArgsDetail";
    };
    Object.defineProperty(WebToggleViewEventArgsDetailDescription.prototype, "id", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
            this.g("Id");
        },
        enumerable: false,
        configurable: true
    });
    WebToggleViewEventArgsDetailDescription.$t = markType(WebToggleViewEventArgsDetailDescription, 'WebToggleViewEventArgsDetailDescription', WebBaseEventArgsDetailDescription.$);
    WebToggleViewEventArgsDetailDescription.__marshalByValue1 = true;
    WebToggleViewEventArgsDetailDescription.__marshalByValueAlias1 = "ToggleViewEventArgsDetail";
    return WebToggleViewEventArgsDetailDescription;
}(WebBaseEventArgsDetailDescription));
export { WebToggleViewEventArgsDetailDescription };
